/*
* file CcResource.java
*
* Licensed Materials - Property of IBM
* Restricted Materials of IBM
* 
* com.ibm.rational.wvcm.stp.cc.CcResource
*
* (C) Copyright IBM Corporation 2004, 2008.  All Rights Reserved. 
* Note to U.S. Government Users Restricted Rights:  Use, duplication or  
* disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
*/


package com.ibm.rational.wvcm.stp.cc;

import javax.wvcm.WvcmException;

import com.ibm.rational.wvcm.stp.StpResource;

/**
 * <p>A proxy for a resource in a ClearCase VOB or view.
 * </p>
 */
public interface CcResource extends StpResource {

    /**
     * Construct a new proxy for this resource. 
     * This new proxy will be of the most correct, most derived class for this
     * resource, based on currently available information in the resource's
     * location, on the local client machine, and/or on the ClearCase server.
     * In addition, this new proxy will have its RESOURCE_IDENTIFIER property
     * correctly set so that its equals() and hashMap() methods will work
     * correctly.
     * <p>Unresolved resource proxies should not be used in situations where
     * equality matters, especially in maps, lists, sets, and other collection
     * classes.
     * </p>
     * @see com.ibm.rational.wvcm.stp.StpResource#equals(Object)
     * @return a new proxy of the correct, most specific resource type
     */
    public CcResource doResolve() throws WvcmException;

    /**
     * Has this proxy already been resolved?
     * @return true if this proxy has been resolved; else false
     * @see #doResolve()
     */
    public boolean isResolved() throws WvcmException;
    
    /**
     * Fetches an instance of a ClearCase provider which can be used for
     * or instantiating proxies for various ClearCase-specific resources.
     * @return An instance of a ClearCase provider
     */
    CcProvider ccProvider();
}
